@@ -27,7 +27,7 @@ else:
 	from defaultpaths import (xdg_config_dir_default, xdg_config_home, 
 							  xdg_data_home, xdg_data_home_default, 
 							  xdg_data_dirs)
-from defaultpaths import (autostart, autostart_home, iccprofiles,
+from defaultpaths import (autostart, autostart_home, home, iccprofiles,
 						  iccprofiles_home)
 from meta import name as appname, build, lastmod, version
 from options import ascii, debug, verbose
@@ -36,6 +36,7 @@ from util_io import StringIOu as StringIO
 from util_os import (expanduseru, expandvarsu, getenvu, is_superuser,
 					 listdir_re, which)
 from util_str import create_replace_function, safe_unicode, strtr
+import colormath
 import encodedstdio
 
 # Runtime configuration
@@ -153,6 +154,7 @@ resfiles = [
 	"ref/ClayRGB1998.gam",
 	"ref/sRGB.gam",
 	"ref/verify_extended.ti1",
+	"ti1/d3-e4-s2-g25-m0-b0-f0.ti1",
 	"ti1/d3-e4-s0-g25-m3-b3-f0-crossover.ti1",
 	"ti1/d3-e4-s0-g49-m3-b3-f0-crossover.ti1",
 	"ti1/d3-e4-s13-g37-m4-b4-f0.ti1",
@@ -464,6 +466,12 @@ def get_icon_bundle(sizes, name):
 	""" Return a wx.IconBundle with given icon sizes """
 	from wxaddons import wx
 	iconbundle = wx.IconBundle()
+	if not sizes:
+		# Assume ICO format
+		ico = get_data_path("theme/icons/%s.ico" % name)
+		if ico:
+			iconbundle.AddIconFromFile(ico, wx.BITMAP_TYPE_ICO)
+			return iconbundle
 	for size in sizes:
 		iconbundle.AddIcon(get_bitmap_as_icon(size, name, False))
 	return iconbundle
@@ -510,7 +518,8 @@ def get_data_path(relpath, rex=None):
 		return None
 	dirs = list(data_dirs)
 	argyll_dir = (getcfg("argyll.dir") or
-				  os.path.dirname(os.path.realpath(which("dispcal") or "")))
+				  os.path.dirname(os.path.realpath(which("dispcal" +
+														 exe_ext) or "")))
 	if argyll_dir and os.path.isdir(os.path.join(argyll_dir, "..", "ref")):
 		dirs.append(os.path.dirname(argyll_dir))
 	dirs.extend(extra_data_dirs)
@@ -624,6 +633,7 @@ cfg = ConfigParser.RawConfigParser()
 cfg.optionxform = str
 
 valid_ranges = {
+	"3dlut.hdr_peak_luminance": [120, 10000],
 	"3dlut.trc_gamma": [0.000001, 10],
 	"3dlut.trc_output_offset": [0.0, 1.0],
 	"app.port": [1, 65535],
@@ -649,6 +659,10 @@ valid_ranges = {
 	"tc_vrml_black_offset": [0, 40],
 	"webserver.portnumber": [1, 65535],
 	"whitepoint.colortemp": [1000, 15000],
+	"whitepoint.visual_editor.bg_v": [0, 255],
+	"whitepoint.visual_editor.b": [0, 255],
+	"whitepoint.visual_editor.g": [0, 255],
+	"whitepoint.visual_editor.r": [0, 255],
 }
 
 valid_values = {
@@ -659,12 +673,13 @@ valid_values = {
 	# collink: xvYCC output encoding is not supported
 	"3dlut.encoding.output": filter(lambda v: v not in ("T", "x", "X"),
 									video_encodings),
-	"3dlut.format": ["3dl", "cube", "eeColor", "madVR", "mga", "png", "ReShade",
-					 "spi3d"],
+	"3dlut.format": ["3dl", "cube", "eeColor", "icc", "madVR", "mga", "png",
+					 "ReShade", "spi3d"],
 	"3dlut.image.layout": ["h", "v"],
 	"3dlut.image.order": ["rgb", "bgr"],
 	"3dlut.rendering_intent": intents,
-	"3dlut.size": [16, 17, 24, 32, 33, 64, 65],
+	"3dlut.size": [5, 9, 16, 17, 24, 32, 33, 64, 65],
+	"3dlut.trc": ["bt1886", "customgamma", "gamma2.2", "smpte2084.hardclip", "smpte2084.rolloffclip"],
 	"3dlut.trc_gamma_type": ["b", "B"],
 	"calibration.quality": ["v", "l", "m", "h", "u"],
 	"colorimeter_correction.observer": observers,
@@ -700,10 +715,10 @@ valid_values = {
 	"synthprofile.trc_gamma_type": ["g", "G"],
 	"tc_algo": ["", "t", "r", "R", "q", "Q", "i", "I"],  # Q = Argyll >= 1.1.0
 	"tc_vrml_use_D50": [0, 1],
-	"tc_vrml_cie_colorspace": ["DIN99", "DIN99b", "DIN99c", "DIN99d", "LCH(ab)",
-							   "LCH(uv)", "Lab", "Luv", "Lu'v'", "xyY"],
+	"tc_vrml_cie_colorspace": ["DIN99", "DIN99b", "DIN99c", "DIN99d", "ICtCp",
+							   "LCH(ab)", "LCH(uv)", "Lab", "Luv", "Lu'v'", "xyY"],
 	"tc_vrml_device_colorspace": ["HSI", "HSL", "HSV", "RGB"],
-	"testchart.auto_optimize": [0, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18],
+	"testchart.auto_optimize": [0, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18],
 	"trc": ["240", "709", "l", "s", ""],
 	"trc.type": ["g", "G"],
 	"uniformity.cols": [3, 5, 7, 9],
@@ -711,13 +726,27 @@ valid_values = {
 	"whitepoint.colortemp.locus": ["t", "T"]
 }
 
+content_rgb_space = colormath.get_rgb_space("DCI P3")
+crx, cry = content_rgb_space[2:][0][:2]
+cgx, cgy = content_rgb_space[2:][1][:2]
+cbx, cby = content_rgb_space[2:][2][:2]
+cwx, cwy = colormath.XYZ2xyY(*content_rgb_space[1])[:2]
 defaults = {
 	"3d.format": "HTML",
 	"3dlut.apply_black_offset": 0,
 	"3dlut.apply_trc": 1,
 	"3dlut.bitdepth.input": 10,
 	"3dlut.bitdepth.output": 12,
+	"3dlut.content.colorspace.blue.x": cbx,
+	"3dlut.content.colorspace.blue.y": cby,
+	"3dlut.content.colorspace.green.x": cgx,
+	"3dlut.content.colorspace.green.y": cgy,
+	"3dlut.content.colorspace.red.x": crx,
+	"3dlut.content.colorspace.red.y": cry,
+	"3dlut.content.colorspace.white.x": cwx,
+	"3dlut.content.colorspace.white.y": cwy,
 	"3dlut.create": 0,
+	"3dlut.trc": "bt1886",
 	"3dlut.trc_gamma": 2.4,
 	"3dlut.trc_gamma.backup": 2.4,
 	"3dlut.trc_gamma_type": "B",
@@ -728,6 +757,8 @@ defaults = {
 	"3dlut.encoding.output.backup": "n",
 	"3dlut.format": "cube",
 	"3dlut.gamap.use_b2a": 0,
+	"3dlut.hdr_maxcll": 10000,
+	"3dlut.hdr_peak_luminance": 400,
 	"3dlut.image.layout": "h",
 	"3dlut.image.order": "rgb",
 	"3dlut.input.profile": "",
@@ -792,6 +823,7 @@ defaults = {
 																	  version),
 	"dimensions.measureframe": "0.5,0.5,1.5",
 	"dimensions.measureframe.unzoomed": "0.5,0.5,1.5",
+	"dimensions.measureframe.whitepoint.visual_editor": "0.5,0.5,1.5",
 	"display.number": 1,
 	"display_lut.link": 1,
 	"display_lut.number": 1,
@@ -920,17 +952,23 @@ defaults = {
 	"profile.save_path": storage, # directory
 	"profile.type": "X",
 	"profile.update": 0,
+	"profile_loader.buggy_video_drivers":  ";".join(["intel"]),
+	"profile_loader.check_gamma_ramps": 0,
 	"profile_loader.error.show_msg": 1,
+	"profile_loader.exceptions": "",
 	"profile_loader.fix_profile_associations": 0,
 	"profile_loader.known_apps": ";".join(["basiccolor display.exe",
 										   "calclient.exe",
 										   "coloreyes display pro.exe",
+										   "colorhcfr.exe",
 										   "colormunkidisplay.exe",
 										   "colornavigator.exe",
+										   "cpkeeper.exe",
 										   "dell ultrasharp calibration solution.exe",
 										   "hp_dreamcolor_calibration_solution.exe",
 										   "i1profiler.exe",
 										   "icolordisplay.exe",
+										   "spectraview.exe",
 										   "spectraview profiler.exe",
 										   "spyder3elite.exe",
 										   "spyder3express.exe",
@@ -940,9 +978,13 @@ defaults = {
 										   "spyder4pro.exe",
 										   "spyder5elite.exe",
 										   "spyder5express.exe",
-										   "spyder5pro.exe"]),
+										   "spyder5pro.exe",
+										   "dispcal.exe",
+										   "dispread.exe",
+										   "flux.exe"]),
 	"profile_loader.known_window_classes": ";".join(["CalClient.exe"]),
 	"profile_loader.reset_gamma_ramps": 0,
+	"profile_loader.use_madhcnet": 0,
 	"profile_loader.verify_calibration": 0,
 	"recent_cals": "",
 	"report.pack_js": 1,
@@ -1011,7 +1053,6 @@ defaults = {
 	"tc_white_patches": 4,
 	"tc.show": 0,
 	"testchart.auto_optimize": 5,
-	"testchart.auto_optimize.fix_zero_blackpoint": 0,
 	"testchart.file": "auto",
 	"testchart.file.backup": "auto",
 	"testchart.reference": "",
@@ -1037,6 +1078,10 @@ defaults = {
 	"whitepoint.colortemp": 5000,
 	"whitepoint.colortemp.backup": 5000,
 	"whitepoint.colortemp.locus": "t",
+	"whitepoint.visual_editor.bg_v": 255,
+	"whitepoint.visual_editor.b": 255,
+	"whitepoint.visual_editor.g": 255,
+	"whitepoint.visual_editor.r": 255,
 	"whitepoint.x": 0.345741,
 	"whitepoint.x.backup": 0.345741,
 	"whitepoint.y": 0.358666,
@@ -1184,6 +1229,8 @@ def getcfg(name, fallback=True, raw=False):
 		if debug > 1:
 			print name, "- falling back to", value
 	elif name in ("displays", "instruments"):
+		if not value:
+			return []
 		value = [strtr(v, [("%" + hex(ord(os.pathsep))[2:].upper(), os.pathsep),
 						   ("%25", "%")]) for v in value.split(os.pathsep)]
 	return value
@@ -1465,7 +1512,10 @@ def initcfg(module=None):
 		setcfg("calibration.file", defaults["calibration.file"])
 	# Read cfg
 	cfgnames = []
-	if module != "3DLUT-maker":
+	if module not in ("3DLUT-maker", "VRML-to-X3D-converter",
+					  "scripting-client"):
+		# Never read base app cfg for 3D LUT maker, VRML converter and
+		# scripting client
 		cfgnames.append(appbasename)
 	if module:
 		cfgnames.append(cfgbasename)
@@ -1483,7 +1533,10 @@ def initcfg(module=None):
 				cfgfiles.append(cfgfile)
 				# Make user config take precedence
 				break
-	cfgfiles.sort(key=lambda cfgfile: os.stat(cfgfile).st_mtime)
+	if len(cfgfiles) > 1 and (module != "apply-profiles" or
+							  sys.platform != "win32"):
+		# Make most recent file take precedence
+		cfgfiles.sort(key=lambda cfgfile: os.stat(cfgfile).st_mtime)
 	try:
 		cfg.read(cfgfiles)
 		# This won't raise an exception if the file does not exist, only
