@@ -75,6 +75,7 @@ basedir = os.path.dirname(pydir)
 config = {"data": ["tests/*.icc"],
 		  "doc": ["LICENSE.txt",
 				  "README.html",
+				  "README-fr.html",
 				  "screenshots/*.png",
 				  "theme/*.png",
 				  "theme/*.css",
@@ -185,6 +186,7 @@ def create_app_symlinks(dist_dir, scripts):
 	for src, tgt in [("ref", "Reference"),
 					 ("tests", "Tests"),
 					 ("README.html", "README.html"),
+					 ("README-fr.html", "README-fr.html"),
 					 ("LICENSE.txt", "LICENSE.txt")]:
 		tgt = os.path.join(dist_dir, tgt)
 		if os.path.islink(tgt):
@@ -410,6 +412,18 @@ def setup():
 			return pathname.lower().startswith(systemroot + "\\")
 		py2exe.build_exe.isSystemDLL = isSystemDLL
 
+		# Numpy DLL paths fix
+		def numpy_dll_paths_fix():
+			import numpy
+			paths = set()
+			numpy_path = numpy.__path__[0]
+			for dirpath, dirnames, filenames in os.walk(numpy_path):
+				for item in filenames:
+					if item.lower().endswith(".dll"):
+						paths.add(dirpath)
+			sys.path.extend(paths)
+		numpy_dll_paths_fix()
+
 	if do_uninstall:
 		i = sys.argv.index("uninstall")
 		sys.argv = sys.argv[:i] + ["install"] + sys.argv[i + 1:]
@@ -523,7 +537,9 @@ def setup():
 		data_files += get_data(data, "data")
 		data_files += get_data(data, "xtra_package_data", name, sys.platform)
 		if sys.platform == "win32":
-			data_files.extend([(os.path.join(data, "lib"), [sys.executable])])
+			# Add python and pythonw
+			data_files.extend([(os.path.join(data, "lib"), [sys.executable,
+				os.path.join(os.path.dirname(sys.executable), "pythonw.exe")])])
 			# OpenAL DLLs for pyglet
 			openal32 = ctypes.util.find_library("OpenAL32.dll")
 			wrap_oal = ctypes.util.find_library("wrap_oal.dll")
@@ -602,11 +618,16 @@ def setup():
 			# desktop entry under Linux
 			icons = []
 			desktopicons = []
+			if sys.platform == "darwin":
+				largest_icon_size = "128x128"
+			else:
+				largest_icon_size = "256x256"
 			for iconpath in glob.glob(os.path.join(pydir, "theme", "icons", 
 												   dname, "*.png")):
 				if not os.path.basename(iconpath).startswith(name.lower()) or (
 					sys.platform in ("darwin", "win32") and 
-					dname in ("16x16", "32x32")):
+					dname in ("16x16", "32x32", "48x48", largest_icon_size)):
+					# We need all the sizes we use in get_icon_bundle
 					icons.append(iconpath)
 				elif sys.platform not in ("darwin", "win32"):
 					desktopicons.append(iconpath)
@@ -709,7 +730,7 @@ setup(ext_modules=[Extension("%s.lib%s.RealDisplaySizeMM", sources=%r,
 		],
 		"data_files": data_files,
 		"description": description,
-		"download_url": "http://%(domain)s/"
+		"download_url": "https://%(domain)s/download/"
 						"%(name)s-%(version)s.tar.gz" % 
 						{"domain": domain, "name": name, "version": version},
 		"ext_modules": ext_modules,
@@ -731,7 +752,7 @@ setup(ext_modules=[Extension("%s.lib%s.RealDisplaySizeMM", sources=%r,
 		"requires": requires,
 		"provides": [name],
 		"scripts": [],
-		"url": "http://%s/" % domain,
+		"url": "https://%s/" % domain,
 		"version": msiversion if "bdist_msi" in sys.argv[1:] else version
 	}
 
@@ -805,7 +826,9 @@ setup(ext_modules=[Extension("%s.lib%s.RealDisplaySizeMM", sources=%r,
 		tmp_scripts_dir = os.path.join(basedir, "build", "temp.scripts")
 		if not os.path.isdir(tmp_scripts_dir):
 			os.makedirs(tmp_scripts_dir)
-		for script, desc in scripts:
+		apply_profiles_launcher = (appname.lower() + "-apply-profiles-launcher",
+								   appname + " Profile Loader Launcher")
+		for script, desc in scripts + [apply_profiles_launcher]:
 			shutil.copy(os.path.join(basedir, "scripts", script),
 						os.path.join(tmp_scripts_dir, script2pywname(script)))
 		attrs["windows"] = [Target(**{
@@ -817,6 +840,17 @@ setup(ext_modules=[Extension("%s.lib%s.RealDisplaySizeMM", sources=%r,
 			"copyright": u"© %s %s" % (strftime("%Y"), author),
 			"description": desc
 		}) for script, desc in scripts]
+		# Add profile loader launcher
+		attrs["windows"].append(Target(**{
+			"script": os.path.join(tmp_scripts_dir,
+								   script2pywname(apply_profiles_launcher[0])),
+			"icon_resources": [(1, os.path.join(pydir, "theme", "icons", 
+												appname.lower() + "-apply-profiles" +
+												".ico"))],
+			"other_resources": [(24, 1, manifest_xml)],
+			"copyright": u"© %s %s" % (strftime("%Y"), author),
+			"description": apply_profiles_launcher[1]
+		}))
 		console_scripts = [name + "-VRML-to-X3D-converter"]
 		for console_script in console_scripts:
 			console_script_path = os.path.join(tmp_scripts_dir,
@@ -1003,6 +1037,7 @@ setup(ext_modules=[Extension("%s.lib%s.RealDisplaySizeMM", sources=%r,
 					"x3d-viewer",
 					"LICENSE.txt",
 					"README.html",
+					"README-fr.html",
 					"argyll_instruments.json",
 					"beep.wav",
 					"camera_shutter.wav",
@@ -1029,7 +1064,8 @@ setup(ext_modules=[Extension("%s.lib%s.RealDisplaySizeMM", sources=%r,
 					"screenshots",
 					"theme",
 					"LICENSE.txt",
-					"README.html"
+					"README.html",
+					"README-fr.html"
 				]:
 					path = os.path.join(doc, fname)
 					if not path in paths:
@@ -1105,6 +1141,7 @@ setup(ext_modules=[Extension("%s.lib%s.RealDisplaySizeMM", sources=%r,
 					   "edit"]
 		manifest_in.extend(["include LICENSE.txt", "include MANIFEST", 
 							"include MANIFEST.in", "include README.html", 
+							"include README-fr.html",
 							"include *.pyw", "include use-distutils"])
 		manifest_in.append("include " + os.path.basename(sys.argv[0]))
 		manifest_in.append("include " + 
