@@ -24,7 +24,7 @@ from wxaddons import get_platform_window_decoration_size, wx
 from wxMeasureFrame import MeasureFrame
 from wxwindows import (BaseApp, BaseFrame, BitmapBackgroundPanelText,
 					   CustomCheckBox, FileDrop, InfoDialog, TooltipWindow)
-from wxfixes import GenBitmapButton as BitmapButton
+from wxfixes import GenBitmapButton as BitmapButton, wx_Panel
 import colormath
 import config
 import wxenhancedplot as plot
@@ -136,7 +136,7 @@ class CoordinateType(list):
 						n = n[0]
 						##n2 = colormath.XYZ2Lab(0, trc[i][0], 0)[0]
 						n2 = colormath.get_gamma([(i / (len(trc) - 1.0) * 65535, trc[i])], 65535, vmin * 655.35, vmax * 655.35, False)
-						if n2:
+						if n2 and n2[0]:
 							n2 = n2[0]
 							match[(name, exp)] += 1 - (max(n, n2) - min(n, n2)) / n2
 							count += 1
@@ -731,7 +731,7 @@ class LUTFrame(BaseFrame):
 		self.sizer = wx.BoxSizer(wx.VERTICAL)
 		self.SetSizer(self.sizer)
 
-		panel = wx.Panel(self)
+		panel = wx_Panel(self)
 		panel.SetBackgroundColour(BGCOLOUR)
 		self.sizer.Add(panel, flag=wx.EXPAND)
 		panel.SetSizer(wx.FlexGridSizer(0, 5, 0, 8))
@@ -780,11 +780,11 @@ class LUTFrame(BaseFrame):
 		self.client = LUTCanvas(self)
 		self.sizer.Add(self.client, 1, wx.EXPAND)
 		
-		self.box_panel = wx.Panel(self)
+		self.box_panel = wx_Panel(self)
 		self.box_panel.SetBackgroundColour(BGCOLOUR)
 		self.sizer.Add(self.box_panel, flag=wx.EXPAND)
 		
-		self.status = BitmapBackgroundPanelText(self)
+		self.status = BitmapBackgroundPanelText(self, name="statuspanel")
 		self.status.SetMaxFontSize(11)
 		self.status.label_y = 8
 		self.status.textshadow = False
@@ -1865,6 +1865,11 @@ class LUTFrame(BaseFrame):
 	def worker(self):
 		return self.client.worker
 
+	def display_changed(self, event):
+		self.worker.enumerate_displays_and_ports(check_lut_access=False,
+												 enumerate_ports=False,
+												 include_network_devices=False)
+
 
 def main():
 	config.initcfg("curve-viewer")
@@ -1882,8 +1887,8 @@ def main():
 
 def _main(app):
 	app.TopWindow.listen()
-	app.TopWindow.worker.enumerate_displays_and_ports(check_lut_access=False,
-													  enumerate_ports=False)
+	app.TopWindow.display_changed(None)
+	app.TopWindow.Bind(wx.EVT_DISPLAY_CHANGED, app.TopWindow.display_changed)
 	app.TopWindow.display_no, geometry, client_area = app.TopWindow.get_display()
 	app.TopWindow.Bind(wx.EVT_MOVE, app.TopWindow.move_handler, app.TopWindow)
 	display_no = get_argyll_display_number(geometry)
